@@ -9,7 +9,7 @@ import re
 
 from .abc import Criteria
 from .sequence import StrSequence, EnSequence
-from .symbols import SYMBOLS
+from .symbols import SYMBOLS, SYMBOLS_EN
 from .white_list import white_list
 
 
@@ -107,6 +107,27 @@ class IsQuoteClose(Criteria):
             return True
 
 
+class IsSingleQuoteCloseEn(Criteria):
+    def __init__(self):
+        super(IsSingleQuoteCloseEn, self).__init__('IsSingleQuoteCloseEn', SYMBOLS_EN)
+
+    def accept(self, state: EnSequence) -> bool:
+        # -- avoid endless loop -- #
+        if state.reach_right_end():
+            return True
+
+        if state.s_quota_en > 0:
+            if (state.s_quota_en + state.s_quota_left) % 2 == 0:
+                state.reset_s_quota()
+                return True
+            else:
+                return False
+        elif state.quota_left > 0:
+            return False
+        else:
+            return True
+
+
 class IsBookClose(Criteria):
     def __init__(self, symbols: dict):
         super(IsBookClose, self).__init__('IsBookClose', symbols)
@@ -144,6 +165,32 @@ class IsShortSentence(Criteria):
         return False
 
 
+class IsSQuota(Criteria):
+    def __init__(self, value: str):
+        super(IsSQuota, self).__init__('Criteria', SYMBOLS_EN)
+        self.value = value
+        assert self.value in ['en', 'left', 'right']
+        if self.value == 'left':
+            self.pattern = self.symbols['s_quota_left']
+        elif self.value == 'right':
+            self.pattern = self.symbols['quotation_right']
+        else:
+            self.pattern = self.symbols['s_quota_en']
+        self.is_blank = re.compile('^\s+')
+
+    def accept(self, state: StrSequence) -> bool:
+        if self.pattern.match(state.current_value):
+            if state.v_pointer == 0:
+                return True
+            elif state.v_pointer == state.length - 1:
+                return True
+            elif self.is_blank.match(state.pre_value) or self.is_blank.match(state.next_value):
+                return True
+            else:
+                return False
+        return False
+
+
 # --- space --- #
 
 class IsSpace(Criteria):
@@ -238,16 +285,16 @@ class IsLeftQuotaEn(SpecialCondition):
         self.blank = re.compile('\s')
 
     def accept(self, state: StrSequence) -> bool:
-        # if self.symbols['quotation_en'].match(state.current_value) and state.quota_en % 2 != 0 or self.symbols[
-        #     'quotation_left'].match(state.current_value):
-        #     # state.v_pointer = max(0, state.v_pointer - 1)
-        #     return True
-
-        if self.symbols['quotation_en'].match(state.current_value) and (not self.blank.match(state.next_value)) or \
-                self.symbols[
-                    'quotation_left'].match(state.current_value):
+        if self.symbols['quotation_en'].match(state.current_value) and state.quota_en % 2 != 0 or self.symbols[
+            'quotation_left'].match(state.current_value):
             # state.v_pointer = max(0, state.v_pointer - 1)
             return True
+
+        # if self.symbols['quotation_en'].match(state.current_value) and (not self.blank.match(state.next_value)) or \
+        #         self.symbols[
+        #             'quotation_left'].match(state.current_value):
+        #     # state.v_pointer = max(0, state.v_pointer - 1)
+        #     return True
         return False
 
 
@@ -261,10 +308,11 @@ class IsRightQuotaEn(SpecialCondition):
             'quotation_right'].match(state.current_value):
             return True
 
-        if self.symbols['quotation_en'].match(state.current_value) and (not self.blank.match(state.pre_value)) and state.v_pointer > 0 or \
-                self.symbols['quotation_right'].match(state.current_value):
-            # state.v_pointer = max(0, state.v_pointer - 1)
-            return True
+        # if self.symbols['quotation_en'].match(state.current_value) and (
+        #         not self.blank.match(state.pre_value)) and state.v_pointer > 0 or \
+        #         self.symbols['quotation_right'].match(state.current_value):
+        #     # state.v_pointer = max(0, state.v_pointer - 1)
+        #     return True
         return False
 
 
@@ -407,3 +455,19 @@ class NotInWhitelistDotEn(SpecialCondition):
             if v in ['.', '!']:
                 return i + start
         return -1
+
+
+class IsSenetnecDash(SpecialCondition):
+    '''
+    检查是否是引文短句dash
+    '''
+
+    def __init__(self):
+        super(IsSenetnecDash, self).__init__('IsSenetnecDash',SYMBOLS_EN)
+
+    def accept(self, state: StrSequence) -> bool:
+        if self.symbols['dash'].match(state.current_value):
+            return True
+        if self.symbols['short_dash'].match(state.current_value) and self.symbols['short_dash'].match(state.pre_value):
+            return True
+        return False
