@@ -22,8 +22,11 @@ SYMBOLS = {
 
 SYMBOLS_EN = {
     'quotation_left': re.compile('([“])'),
+    's_quota_left': re.compile('([‘])'),
     'quotation_en': re.compile('(["])'),
+    's_quota_en':  re.compile("(['])"),
     'quotation_right': re.compile('([”])'),
+    's_quota_right': re.compile('([’])'),
     'all_quota': re.compile('([“"”])'),
     'bracket_left': re.compile('([<{\[\(（【「])'),
     'bracket_right': re.compile('([\)\]}」】）>])'),
@@ -32,5 +35,7 @@ SYMBOLS_EN = {
     'comma': re.compile('([,，;])'),
     'end_symbols': re.compile('([?\!…;？！。])'),
     'en_dot': re.compile('\.'),
-    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\){\)\s])')
+    'dash': re.compile('—'),
+    'short_dash': re.compile('-'),
+    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\'‘’\-\—\){\)\s])')
 }
